import argparse 
from fgit.actions import push

def main():
    parser = argparse.ArgumentParser(prog ='fgit', description ='FastGit commandline interface') 
    parser.add_argument("action", type=str, help = "action to perform: push.")
    parser.add_argument("-m","--message", type=str, help = "commit message")

    args = parser.parse_args() 
    action = args.action

    if action == "push":
        push("." , message = args.message)


from git.repo.base import Repo
from fgit.utils.git import get_uncommitted
from fgit.utils.message_box import border_msg

def push(repo_path: str, message = "update"):
    ''' 
    Instructional push to an active branch
    '''    
    repo = Repo(repo_path)
    uncommited = get_uncommitted(repo)
    modified, untracked = uncommited["modified"], uncommited["untracked"]
    all_files = modified + untracked
    n_all = len(all_files)
    n_modified = len(modified)
    n_untracked = len(untracked)

    border_msg(f"Active branch: {repo.active_branch}")
    
    # Print uncommited (list by number)
    for i, file in enumerate(all_files):
        # Print header
        if i == 0 and n_modified!=0:
            print("\n● Modified:")
        elif i == n_modified and n_untracked!=0:
            print("\n● Untracked:")
        print(f"[{i}] {file}")
    if n_all != 0:
        committed_ids = [int(i) for i in input("\nCommit ids: ").split()]
    else:
        print("Nothing to commit.")
    commited_files = [file for i, file in enumerate(all_files) if i in committed_ids]
    commit_message = input("Commit message: ")

    repo.index.add(commited_files)
    repo.index.commit(commit_message)
    
    repo.git.push("origin", repo.active_branch)
    print(f"Woohoo!~ Pushed to {repo.remotes.origin.url}| branch: {repo.active_branch}")



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

# Setup tools
setuptools.setup(
     name='fgit',
     version='0.0.1b4',
     author="Truong-Phat Nguyen",
     author_email="me@patrickphat.com",
     description="FGIT: No longer wait for another git commit",
     long_description=long_description,
     long_description_content_type="text/markdown",
     url="https://github.com/patrick/fgit",
     packages=setuptools.find_packages(exclude=['docs', 'tests', 'experiments']),
     entry_points ={ 
            'console_scripts': [ 
                'fgit = cli.main:main'
            ]
     },
     classifiers=[
         "Programming Language :: Python :: 3",
         "License :: OSI Approved :: MIT License",
         "Operating System :: OS Independent",
     ],
     python_requires='>3.6',
     install_requires =[
         "GitPython",
         ],
     extras_require={
         'dev': [
             'pytest',
             'coverage',
             ],
     }
 )


from git import Repo

def get_uncommitted(repo_obj: Repo):
    result_dict = {
        "modified": get_modified(repo_obj),
        "untracked": get_untracked(repo_obj),
    }
    return result_dict

def get_untracked(repo_obj):
    return repo_obj.untracked_files

def get_modified(repo_obj):
    changed_files = [item.a_path for item in repo_obj.index.diff(None)]
    return changed_files